@@ -39,15 +39,8 @@ namespace Givaro {
 
         using Parent_t::Parent_t; // inherit constructors
 
-        int operator==( const Self_t&) const
-        {
-            return 1;
-        }
-        int operator!=( const Self_t&) const
-        {
-            return 0;
-        }
-
+        int operator==( const Self_t&) const { return 1; }
+        int operator!=( const Self_t&) const { return 0; }
 
         template<class XXX> XXX& convert(XXX& x, const Rep& a) const
         {
@@ -179,6 +172,19 @@ namespace Givaro {
             return g;
         }
 
+            // Inverse in Z
+        Rep& inv(Rep& u, const Rep& a) const
+        {
+            if (isUnit(a)) return assign(u,a);
+            else throw GivMathError("*** Error: non invertible in ZRing.inv") ;
+        }
+        Rep& invin(Rep& u) const
+        {
+            if (isUnit(u)) return u;
+            else throw GivMathError("*** Error: non invertible in ZRing.invin") ;
+        }
+
+            // Modular inverses
         Rep& inv(Rep& u, const Rep& a, const Rep& b) const
         {
             return ::Givaro::inv(u,a,b);
@@ -197,14 +203,14 @@ namespace Givaro {
             return invin(u,b);
         }
 
-        bool ratrecon(Rep& num, Rep& den, const Rep& f, const Rep& m, 
-                      const Rep& numbound, 
+        bool ratrecon(Rep& num, Rep& den, const Rep& f, const Rep& m,
+                      const Rep& numbound,
                       bool forcereduce = true, bool recurs = true) const ;
         bool RationalReconstruction(Rep&, Rep&, const Rep&, const Rep&) const;
-        bool RationalReconstruction(Rep&, Rep&, 
-                                    const Rep&, const Rep&, const Rep&, 
+        bool RationalReconstruction(Rep&, Rep&,
+                                    const Rep&, const Rep&, const Rep&,
                                     bool = true, bool = true) const ;
-        bool RationalReconstruction(Rep&, Rep&, const Rep&, const Rep&, 
+        bool RationalReconstruction(Rep&, Rep&, const Rep&, const Rep&,
                                     const Rep&, const Rep&) const;
         // - return n^l
         Rep& pow(Rep& r, const Rep& n, const int64_t l) const
@@ -281,7 +287,9 @@ namespace Givaro {
          */
         inline  bool isDivisor (const Element& a, const Element& b) const
         {
-            Element r; return ::Givaro::isZero(mod(r,a,b));
+            Element r;
+            if (::Givaro::isZero(b)) return ::Givaro::isZero(a);
+            return ::Givaro::isZero(mod(r,a,b));
         }
 
         Element& abs(Element& x, const Element& a) const {
@@ -416,9 +424,9 @@ namespace Givaro {
 //                                 const Integer& f, const Integer& m,
 //                                 const Integer& k,
 //                                 bool forcereduce, bool recursive );
-//     bool ratrecon(Integer& num, Integer& den, 
-//                   const Integer& f, const Integer& m, 
-//                   const Integer& k, 
+//     bool ratrecon(Integer& num, Integer& den,
+//                   const Integer& f, const Integer& m,
+//                   const Integer& k,
 //                   bool forcereduce = true, bool recurs = true );
 
 } // Givaro
