@@ -154,10 +154,13 @@ namespace Givaro
         typedef GeneralRingNonZeroRandIter<Self_t> NonZeroRandIter;
         template< class Random > Element& random(Random& g, Element& r) const
         { return init(r, g()); }
-        template< class Random > Element& nonzerorandom(Random& g, Element& a) const
-        { while (isZero(init(a, g())))
-            ;
-            return a; }
+        template< class Random >
+        Element& nonzerorandom(Random& g, Element& a) const {
+            do {
+                init(a,g());
+            } while (isZero(a));
+            return a;
+        }
 
         // --- IO methods
         std::ostream& write(std::ostream& s) const;
