@@ -18,16 +18,8 @@
 
 #include <givaro/givconfig.h>
 
-#include "givaro/modular-int8.h"
-#include "givaro/modular-uint8.h"
-#include "givaro/modular-int16.h"
-#include "givaro/modular-uint16.h"
-#include "givaro/modular-int32.h"
-#include "givaro/modular-uint32.h"
-#include "givaro/modular-int64.h"
-#include "givaro/modular-uint64.h"
-#include "givaro/modular-float.h"
-#include "givaro/modular-double.h"
+#include "givaro/modular-integral.h"
+#include "givaro/modular-floating.h"
 #include "givaro/modular-integer.h"
 #include "givaro/modular-inttype.h"
 #include "givaro/modular-log16.h"
@@ -35,3 +27,5 @@
 
 #endif
 
+/* -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
